@@ -3,6 +3,6 @@ function(fmodel, y, zmin = -5, zmax = 5, ...)
 {
 	tmp <- optimize(function(zeta, ...) fmodel(zeta, ...)$post, 
 		interval = c(zmin, zmax), maximum = TRUE, y = y, ...)
-	names(tmp) <- c("zeta", "lmax")
+	names(tmp) <- c("zeta", "post")
 	return(tmp)
 }
\ No newline at end of file
